pub struct AnalysisProvenance {
pub category: AnalysisCategory,
pub rule_id: String,
pub confidence: u8,
pub evidence: Vec<NoteAddr>,
pub label: Option<String>,
}Expand description
One deterministic explanation attached to a source note address.
Fields
category: AnalysisCategoryrule_id: Stringconfidence: u8evidence: Vec<NoteAddr>label: Option<String>Canonical display label when the finding is a chord explanation.