AnalysisPass

Trait AnalysisPass 

pub trait AnalysisPass {
    // Required methods
    fn id(&self) -> &str;
    fn run(&self, score: &Score) -> Value;
}
A host- or application-provided deterministic analysis extension.

Required Methods

fn id(&self) -> &str

Stable identifier used for ordering and persisted result lookup.

fn run(&self, score: &Score) -> Value

Run the pass over a score and return its JSON payload.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors